=== modified file 'lib/lp/registry/browser/team.py'
--- lib/lp/registry/browser/team.py	2011-08-06 08:00:21 +0000
+++ lib/lp/registry/browser/team.py	2011-08-07 04:05:52 +0000
@@ -563,25 +563,25 @@
             "Mailing list application cancelled.")
         self.next_url = canonical_url(self.context)
 
-    def request_list_creation_validator(self, action, data):
-        """Validator for the `request_list_creation` action.
+    def create_list_creation_validator(self, action, data):
+        """Validator for the `create_list_creation` action.
 
-        Adds an error if someone tries to request a mailing list for a
+        Adds an error if someone tries to create a mailing list for a
         team that already has one. This can only happen through
         bypassing the UI.
         """
-        if not self.list_can_be_requested:
+        if not self.list_can_be_created:
             self.addError(
                 "You cannot create a new mailing list for this team.")
 
-    @action('Create new Mailing List', name='request_list_creation',
-            validator=request_list_creation_validator)
-    def request_list_creation(self, action, data):
+    @action('Create new Mailing List', name='create_list_creation',
+            validator=create_list_creation_validator)
+    def create_list_creation(self, action, data):
         """Creates a new mailing list."""
         getUtility(IMailingListSet).new(self.context)
         self.request.response.addInfoNotification(
-            "Launchpad will now add a mailing list to this team. You "
-            "should recieve an email confirmation in a few minutes.")
+            "The mailing list is being created and will be available for "
+            "use in a few minutes.")
         self.next_url = canonical_url(self.context)
 
     def deactivate_list_validator(self, action, data):
@@ -715,8 +715,8 @@
         return self.getListInState(MailingListStatus.REGISTERED) is not None
 
     @property
-    def list_can_be_requested(self):
-        """Can a mailing list be requested for this team?
+    def list_can_be_created(self):
+        """Can a mailing list be created for this team?
 
         It can only be requested if there's no mailing list associated with
         this team, or the mailing list has been purged.

=== modified file 'lib/lp/registry/browser/tests/mailinglist-views.txt'
--- lib/lp/registry/browser/tests/mailinglist-views.txt	2011-05-27 19:53:20 +0000
+++ lib/lp/registry/browser/tests/mailinglist-views.txt	2011-08-07 04:05:52 +0000
@@ -158,7 +158,7 @@
 
     >>> list_one.purge()
     >>> view = create_view(the_owner)
-    >>> view.list_can_be_requested
+    >>> view.list_can_be_created
     True
     >>> view.list_can_be_deactivated
     False

=== modified file 'lib/lp/registry/stories/mailinglists/lifecycle.txt'
--- lib/lp/registry/stories/mailinglists/lifecycle.txt	2011-08-06 08:00:21 +0000
+++ lib/lp/registry/stories/mailinglists/lifecycle.txt	2011-08-07 04:05:52 +0000
@@ -31,10 +31,10 @@
     Landscape Developers in Launchpad
     >>> for msg in get_feedback_messages(browser.contents):
     ...     print msg
-    Launchpad will now add a mailing list to this team. You should recieve an email confirmation in a few minutes.
+    The mailing list is being created and will be available for use in a few minutes.
 
-Once the mailing list is requested, the button to request its activation is
-not shown anymore.
+Once the mailing list is created, the button to create it is not shown
+anymore.
 
     >>> browser.getControl('Create new Mailing List')
     Traceback (most recent call last):
@@ -56,7 +56,7 @@
     >>> print find_tag_by_id(browser.contents, 'mailing-list-archive')
     None
 
-Even after the list has been requested, it still cannot be used as the contact
+Even after the list has been created, it still cannot be used as the contact
 address until Mailman has acknowledged successful creation.
 
     >>> browser.reload()
@@ -374,10 +374,10 @@
     PURGED
     >>> admin_browser.open('http://launchpad.dev/~aardvarks/+mailinglist')
     >>> admin_browser.getControl('Create new Mailing List')
-    <SubmitControl name='field.actions.request_list_creation' type='submit'>
+    <SubmitControl name='field.actions.create_list_creation' type='submit'>
     >>> expert_browser.open('http://launchpad.dev/~aardvarks/+mailinglist')
     >>> expert_browser.getControl('Create new Mailing List')
-    <SubmitControl name='field.actions.request_list_creation' type='submit'>
+    <SubmitControl name='field.actions.create_list_creation' type='submit'>
 
 The team owner can see that an inactive list can be reactivated or purged.
 

=== modified file 'lib/lp/registry/templates/team-mailinglist.pt'
--- lib/lp/registry/templates/team-mailinglist.pt	2011-06-30 13:55:40 +0000
+++ lib/lp/registry/templates/team-mailinglist.pt	2011-08-07 04:05:52 +0000
@@ -34,7 +34,7 @@
 
     <metal:widgets fill-slot="widgets">
       <div id="no_mailing_list"
-         tal:condition="view/list_can_be_requested">
+         tal:condition="view/list_can_be_created">
         <p>
           You can create a mailing list for this team. Team members
           can subscribe and post to the team mailing list.
@@ -63,7 +63,7 @@
         <p>
           &#187; <a href="https://help.launchpad.net/Teams/MailingLists">Help for mailing lists</a>
         </p>
-        <input tal:replace="structure view/request_list_creation/render" />
+        <input tal:replace="structure view/create_list_creation/render" />
       </div>
 
       <div id="mailing_list_purge"

